@@ -3,7 +3,7 @@
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License as
-   published by the Free Software Foundation; either version 3 of the
+   published by the Free Software Foundation; either version 2 of the
    License, or (at your option) any later version.
 
    This program is distributed in the hope that it will be useful, but
@@ -1204,7 +1204,8 @@ parse_command_line (int argc, char **argv)
     "This is free software; see the source for copying conditions.  "
     "There is NO\n"
     "WARRANTY; not even for MERCHANTABILITY or FITNESS FOR A "
-    "PARTICULAR PURPOSE.\n\n";
+    "PARTICULAR PURPOSE.\n\n"
+    "Written by Ben Pfaff <blp@gnu.org>.\n";
   
   const char *short_pgm_name = strrchr (argv[0], '/');
   if (short_pgm_name != NULL)
