@@ -3,7 +3,7 @@
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License as
-   published by the Free Software Foundation; either version 3 of the
+   published by the Free Software Foundation; either version 2 of the
    License, or (at your option) any later version.
 
    This program is distributed in the hope that it will be useful, but
@@ -379,7 +379,7 @@ main (int argc, char *argv[])
 	 "\nOptions:\n"
 	 "  -w WIDTH  page width for centering, WIDTH in characters (text)\n"
 	 "            or 1/1000 point (PostScript), default 72 or 612000\n"
-	 "\nReport bugs to bug-avl@gnu.org.\n", argv[0]);
+	 "\nReport bugs to Ben Pfaff <blp@gnu.org>.\n", argv[0]);
 
       return argc == 2 ? EXIT_SUCCESS : EXIT_FAILURE;
     }
@@ -393,7 +393,8 @@ main (int argc, char *argv[])
 	 "not even for MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.\n"
 	 "You may redistribute copies of texiweb under the terms of the GNU\n"
 	 "General Public License.  For more information about these\n"
-	 "matters, see the file named COPYING.\n");
+	 "matters, see the file named COPYING.\n"
+	 "Written by Ben Pfaff <blp@gnu.org>.\n");
 
       return EXIT_SUCCESS;
     }
